#ifndef DRIVERS_TLC5971_H_
#define DRIVERS_TLC5971_H_

#include <msp430.h>
#include <stdint.h>

//clock and data pins
#define SCK_PIN BIT3
#define SDT_PIN BIT1

//218 bit data latch setup
#define BLANK   BIT5
#define DSPRPT  BIT6
#define TMGRST  BIT7
#define EXTGCK  BIT0
#define OUTTMG  BIT1
#define WRITECMD 0x94

//State
#define OFF 0x00
#define ON 	0x01

//Colors
#define RED   0
#define GREEN 1
#define BLUE  2
#define AMBER 3
#define WHITE 4
#define GREEN_OR_BLUE   GREEN
#define BLUE_OR_GREEN   BLUE

//Number of lamps
#define LAMP_ONE   0
#define LAMP_TWO   1
#define LAMP_THREE 2
#define LAMP_FOUR  3
#define LAMP_FIVE  4

//Condition
#define START   1
#define STOP 	2

//Limit
#define DIVIDE    10
#define THRESH_OFF 5

//Leds and Buttons
#define BUTTON1 BIT4 //S2 connected to P1.4
#define BUTTON2 BIT5 //S3 connected to P1.5
#define LED1    BIT6 //D18 connected to P1.6
#define LED2    BIT7 //D19 connected to P1.7

//Number of rows
#define ROW_ONE 	1
#define ROW_TWO 	0
#define ROW_THREE	3
#define ROW_FOUR 	2


//Function declaration
void write(char data);
void blank(char lamp, char status);
void setGlobalBrightness(char lamp, char color, char value);
void setBrightness(char lamp, char row, char color, char value);
char getBrightness(char lamp, char row, char color);
void setColor(char lamp, char row, char red, char green, char blue);
void sendData();
void delay(int i);


#endif /* DRIVERS_TLC5971_H_ */
